@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2016-01-14'; # DATE
-our $VERSION = '0.30'; # VERSION
+our $DATE = '2016-06-02'; # DATE
+our $VERSION = '0.31'; # VERSION
 
 use 5.010001;
 use strict;
@@ -45,8 +45,9 @@ has code_before_instantiate_cmdline => (is=>'rw');
 has code_after_end => (is=>'rw');
 has skip_format => (is=>'rw');
 has use_utf8 => (is=>'rw');
+has allow_prereq => (is=>'rw');
 
-sub mvp_multivalue_args { qw(build_load_modules load_modules code_before_instantiate_cmdline code_after_end config_filename config_dirs) }
+sub mvp_multivalue_args { qw(build_load_modules load_modules code_before_instantiate_cmdline code_after_end config_filename config_dirs allow_prereq) }
 
 sub gather_files {
     # we actually don't generate scripts in this phase but in the later stage
@@ -148,6 +149,7 @@ sub munge_files {
             (exclude_package_functions_match => $self->exclude_package_functions_match) x !!$self->exclude_package_functions_match,
             skip_format => $self->skip_format ? 1:0,
             use_utf8 => $self->use_utf8,
+            (allow_prereq => $self->allow_prereq) x !!$self->allow_prereq,
         );
         #use DD; dd \%gen_args;
         $res = gen_pericmd_script(%gen_args);
@@ -239,7 +241,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.30 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2016-01-14.
+This document describes version 0.31 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2016-06-02.
 
 =head1 SYNOPSIS
 
@@ -319,15 +321,15 @@ of SUBCOMMAND_NAME:URL[:SUMMARY]. Example:
 
 =head2 subcommands_from_package_functions => bool
 
-Will be passed to App::GenPericmdScript::gen_perinci_cmdline_script() backend.
+Will be passed to Perinci::CmdLine::Gen backend.
 
 =head2 include_package_functions_match => re
 
-Will be passed to App::GenPericmdScript::gen_perinci_cmdline_script() backend.
+Will be passed to Perinci::CmdLine::Gen backend.
 
 =head2 exclude_package_functions_match => re
 
-Will be passed to App::GenPericmdScript::gen_perinci_cmdline_script() backend.
+Will be passed to Perinci::CmdLine::Gen backend.
 
 =head2 name => str
 
@@ -336,8 +338,7 @@ with C<_> replaced to C<->.
 
 =head2 summary => str
 
-Will be passed to C<script_summary> in
-App::GenPericmdScript::gen_perinci_cmdline_script() backend.
+Will be passed to Perinci::CmdLine::Gen backend (as C<script_summary>).
 
 =head2 cmdline => str
 
@@ -404,21 +405,16 @@ Passed to Perinci::CmdLine object construction code.
 
 Passed to Perinci::CmdLine object construction code.
 
+=head2 allow_prereq => bool
+
+Will be passed to Perinci::CmdLine::Gen backend.
+
 =head1 CONFIGURATION (OTHER)
 
 =head2 build_load_modules => array[str]
 
 Load modules during build process.
 
-=head1 SEE ALSO
-
-L<Rinci>
-
-L<Pod::Weaver::Plugin::Rinci> to fill more stuffs to the POD of the generated
-script.
-
-C<Dist::Zilla::Plugin::Rinci::*> for plugins that utilize Rinci metadata.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-Plugin-GenPericmdScript>.
@@ -435,6 +431,15 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Rinci>
+
+L<Pod::Weaver::Plugin::Rinci> to fill more stuffs to the POD of the generated
+script.
+
+C<Dist::Zilla::Plugin::Rinci::*> for plugins that utilize Rinci metadata.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
